@@ -12,6 +12,6 @@ def register(linter):
     linter.register_checker(SelectAliasChecker(linter))
     linter.register_checker(SelectCastChecker(linter))
     linter.register_checker(StatementCallChecker(linter))
-    linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
     linter.register_checker(ConfluencePageChecker(linter))
+    # linter.register_checker(ChainedDotFunctionsSyntaxChecker(linter))
 
